@@ -1,17 +1,23 @@
 use crate::error::{Error, Result};
 use std::env;
 
-#[derive(PartialEq, Default, Debug)]
-pub(crate) enum Update {
-    #[default]
+#[derive(PartialEq, Debug)]
+pub enum Update {
     Wip,
     Overwrite,
 }
 
+impl Default for Update {
+    fn default() -> Self {
+        Update::Wip
+    }
+}
+
 impl Update {
     pub fn env() -> Result<Self> {
-        let Some(var) = env::var_os("TRYBUILD") else {
-            return Ok(Update::default());
+        let var = match env::var_os("TRYBUILD2") {
+            Some(var) => var,
+            None => return Ok(Update::default()),
         };
 
         match var.as_os_str().to_str() {
