@@ -1,6 +1,6 @@
 use crate::error::{Error, Result};
 use crate::manifest::Name;
-use crate::Test;
+use crate::{Test, TestKind};
 use std::collections::BTreeMap as Map;
 use std::path::PathBuf;
 
@@ -19,9 +19,19 @@ pub(crate) fn expand_globs(tests: &[Test]) -> Vec<ExpandedTest> {
         match test.path.to_str() {
             Some(utf8) if utf8.contains('*') => match glob(utf8) {
                 Ok(paths) => {
-                    let expected = test.expected;
+                    if matches!(test.inner, TestKind::Inline(_)) {
+                        panic!("'*' isn't allowed in inline test names: `{}`", utf8);
+                    }
                     for path in paths {
-                        set.insert(Test { path, expected }, None, true);
+                        set.insert(
+                            Test {
+                                expected: test.expected.clone(),
+                                path,
+                                inner: TestKind::File,
+                            },
+                            None,
+                            true,
+                        );
                     }
                 }
                 Err(error) => set.insert(test.clone(), Some(error), false),
