@@ -1,4 +1,5 @@
 use crate::error::Result;
+use once_cell::sync::OnceCell;
 use std::fs::{self, File, OpenOptions};
 use std::io;
 use std::path::{Path, PathBuf};
@@ -7,9 +8,9 @@ use std::sync::{Arc, Mutex, MutexGuard, PoisonError};
 use std::thread;
 use std::time::{Duration, SystemTime};
 
-static LOCK: Mutex<()> = Mutex::new(());
+static LOCK: OnceCell<Mutex<()>> = OnceCell::new();
 
-pub(crate) struct Lock {
+pub struct Lock {
     intraprocess_guard: Guard,
     lockfile: FileLock,
 }
@@ -18,7 +19,7 @@ pub(crate) struct Lock {
 // integration test crate.
 enum Guard {
     NotLocked,
-    Locked(#[allow(dead_code)] MutexGuard<'static, ()>),
+    Locked(MutexGuard<'static, ()>),
 }
 
 // Best-effort filesystem lock to coordinate different #[test] functions across
@@ -42,15 +43,20 @@ impl Lock {
 
 impl Guard {
     fn acquire() -> Self {
-        Guard::Locked(LOCK.lock().unwrap_or_else(PoisonError::into_inner))
+        Guard::Locked(
+            LOCK.get_or_init(|| Mutex::new(()))
+                .lock()
+                .unwrap_or_else(PoisonError::into_inner),
+        )
     }
 }
 
 impl FileLock {
     fn acquire(path: impl AsRef<Path>) -> Result<Self> {
         let path = path.as_ref().to_owned();
-        let Some(lockfile) = create(&path) else {
-            return Ok(FileLock::NotLocked);
+        let lockfile = match create(&path) {
+            None => return Ok(FileLock::NotLocked),
+            Some(lockfile) => lockfile,
         };
         let done = Arc::new(AtomicBool::new(false));
         let thread = thread::Builder::new().name("trybuild-flock".to_owned());
@@ -109,8 +115,9 @@ fn create(path: &Path) -> Option<File> {
             },
         };
 
-        let Ok(modified) = metadata.modified() else {
-            return None;
+        let modified = match metadata.modified() {
+            Ok(modified) => modified,
+            Err(_) => return None,
         };
 
         let now = SystemTime::now();
