@@ -220,7 +220,7 @@
 //! If you need  more control over the stderr check as well, you can take a
 //! look at `compile_fail_check_sub` and `compile_fail_inline_check_sub`.
 
-#![doc(html_root_url = "https://docs.rs/trybuild2/1.0.2")]
+#![doc(html_root_url = "https://docs.rs/trybuild2/1.2.0")]
 #![allow(
     clippy::collapsible_if,
     clippy::default_trait_access,
@@ -239,6 +239,7 @@
     clippy::range_plus_one,
     clippy::similar_names,
     clippy::single_match_else,
+    clippy::test_attr_in_doctest,
     clippy::too_many_lines,
     clippy::trivially_copy_pass_by_ref,
     clippy::unused_self,
@@ -269,6 +270,7 @@ mod run;
 mod rustflags;
 
 use std::cell::RefCell;
+use std::ffi::OsString;
 use std::panic::RefUnwindSafe;
 use std::path::{Path, PathBuf};
 use std::thread;
@@ -280,6 +282,7 @@ pub struct TestCases {
 
 #[derive(Debug)]
 struct Runner {
+    suffix: Option<OsString>,
     tests: Vec<Test>,
 }
 
@@ -315,7 +318,35 @@ impl TestCases {
     #[allow(clippy::new_without_default)]
     pub fn new() -> Self {
         TestCases {
-            runner: RefCell::new(Runner { tests: Vec::new() }),
+            runner: RefCell::new(Runner {
+                suffix: None,
+                tests: Vec::new(),
+            }),
+        }
+    }
+
+    /// Will add a custom suffix to stderr files.
+    ///
+    /// This can be useful to test both nightly and stable outputs.
+    /// ```no_run
+    /// # use trybuild2::TestCases;
+    /// #[rustversion::nightly]
+    /// fn nightly() {
+    ///     let runner = TestCases::with_suffix("nightly");
+    ///     // ...
+    /// }
+    /// #[rustversion::stable]
+    /// fn stable() {
+    ///     let runner = TestCases::with_suffix("stable");
+    ///     // ...
+    /// }
+    /// ```
+    pub fn with_suffix(suffix: impl Into<OsString>) -> Self {
+        TestCases {
+            runner: RefCell::new(Runner {
+                suffix: Some(suffix.into()),
+                tests: Vec::new(),
+            }),
         }
     }
 
